@@ -9,7 +9,10 @@ OC.L10N.register(
     "Please see Nextcloud server log for details." : "Se Nextcloud serverlogg för mer information.",
     "Deleted {title}" : "Raderad {title}",
     "Undo Delete" : "Ångra radering",
+    "Note recovered" : "Anteckning återskapad",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["Tog bort {number} anteckning","Tog bort {number} anteckningar"],
+    "_Recovered {number} note_::_Recovered {number} notes_" : ["Återskapade {number} anteckning","Återskapade {number} anteckningar"],
     "Settings" : "Inställningar",
     "Folder to store your notes" : "Mapp för att spara dina anteckningar",
     "path to notes" : "sökväg till anteckningar",
@@ -30,6 +33,9 @@ OC.L10N.register(
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till som favorit",
     "Error during preparing note for deletion." : "Fel vid förberedelse av anteckning för radering.",
+    "The note has been changed in another session. Please choose which content should be saved." : "Anteckningen har modifierats i en annan session. Vänligen välj vilket innehåll som skall sparas.",
+    "Use version from server" : "Använd version från servern",
+    "Use current version" : "Använd nuvarande version",
     "Empty note" : "Tom anteckning",
     "Write …" : "Skriv ...",
     "Details" : "Detaljer",
@@ -38,7 +44,9 @@ OC.L10N.register(
     "Preview" : "Förhandsvisa",
     "Exit full screen" : "Avsluta fullskärm",
     "Full screen" : "Fullskärm",
+    "Note is read-only. You cannot change it." : "Anteckningen är skrivskyddad. Du kan inte ändra den.",
     "Save failed. Click to retry." : "Kunde inte spara. Klicka för att försöka igen.",
+    "Update conflict. Click for resolving manually." : "Uppdateringskonflikt. Klicka för att lösa upp manuellt.",
     "Set category" : "Ange kategori",
     "Category" : "Kategori",
     "Uncategorized" : "Okategoriserad",
@@ -62,6 +70,7 @@ OC.L10N.register(
     "Insufficient storage." : "Otillräckligt utrymme.",
     "See JavaScript console and server log for details." : "Se JavaScript-konsol och serverlogg för detaljer.",
     "Updating settings has failed." : "Kunde inte uppdatera inställningar. ",
+    "Fetching notes for dashboard has failed." : "Hämtning av anteckningar för dashboarden misslyckades",
     "Error from Nextcloud server: {msg}" : "Fel från Nextcloud server: {msg}",
     "Fetching notes has failed." : "Kunde inte hämta anteckningar.",
     "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
