@@ -49,31 +49,12 @@ class NotesController extends Controller {
 		$this->l10n = $l10n;
 	}
 
-	private function getNotesAndCategories(string $userId, int $pruneBefore) : array {
-		$data = $this->notesService->getAll($userId);
-		$metas = $this->metaService->updateAll($userId, $data['notes']);
-		$notes = array_map(function ($note) use ($metas, $pruneBefore) {
-			$lastUpdate = $metas[$note->getId()]->getLastUpdate();
-			if ($pruneBefore && $lastUpdate < $pruneBefore) {
-				return [ 'id' => $note->getId() ];
-			} else {
-				return $note->getData([ 'content' ]);
-			}
-		}, $data['notes']);
-		return [
-			'notes' => $notes,
-			'categories' => $data['categories'],
-		];
-	}
-
-
 	/**
 	 * @NoAdminRequired
 	 */
 	public function index(int $pruneBefore = 0) : JSONResponse {
 		return $this->helper->handleErrorResponse(function () use ($pruneBefore) {
 			$userId = $this->helper->getUID();
-			$now = new \DateTime(); // this must be before loading notes if there are concurrent changes possible
 			$settings = $this->settingsService->getAll($userId);
 
 			$lastViewedNote = (int) $this->settings->getUserValue(
@@ -82,32 +63,33 @@ class NotesController extends Controller {
 				'notesLastViewedNote'
 			);
 			$errorMessage = null;
-			$notes = null;
-			$categories = null;
+			$nac = null;
 
 			try {
-				$nac = $this->getNotesAndCategories($userId, $pruneBefore);
-				[ 'notes' => $notes, 'categories' => $categories ] = $nac;
+				$nac = $this->helper->getNotesAndCategories($pruneBefore, [ 'etag', 'content' ]);
 			} catch (\Throwable $e) {
 				$this->helper->logException($e);
 				$errorMessage = $this->l10n->t('Reading notes from filesystem has failed.').' ('.get_class($e).')';
 			}
 
-			if ($errorMessage === null && $lastViewedNote && is_array($notes) && !count($notes)) {
+			if ($errorMessage === null && $lastViewedNote
+				&& is_array($nac) && is_array($nac['notesAll']) && !count($nac['notesAll'])
+			) {
 				$this->settings->deleteUserValue($userId, $this->appName, 'notesLastViewedNote');
 				$lastViewedNote = 0;
 			}
 
 			$result = [
-				'notes' => $notes,
-				'categories' => $categories,
+				'notesData' => array_values($nac['notesData'] ?? null),
+				'noteIds' => array_keys($nac['notesAll']),
+				'categories' => $nac['categories'] ?? null,
 				'settings' => $settings,
 				'lastViewedNote' => $lastViewedNote,
 				'errorMessage' => $errorMessage,
 			];
 			$etag = md5(json_encode($result));
 			return (new JSONResponse($result))
-				->setLastModified($now)
+				->setLastModified($nac['lastUpdate'] ?? null)
 				->setETag($etag)
 			;
 		});
@@ -161,10 +143,9 @@ class NotesController extends Controller {
 				strval($id)
 			);
 
-			$result = $note->getData();
-			$etag = md5(json_encode($result));
-			return (new JSONResponse($result))
-				->setETag($etag)
+			$noteData = $this->helper->getNoteData($note);
+			return (new JSONResponse($noteData))
+				->setETag($noteData['etag'])
 			;
 		});
 	}
@@ -176,7 +157,7 @@ class NotesController extends Controller {
 	public function create(string $category) : JSONResponse {
 		return $this->helper->handleErrorResponse(function () use ($category) {
 			$note = $this->notesService->create($this->helper->getUID(), '', $category);
-			return $note->getData();
+			return $this->helper->getNoteData($note);
 		});
 	}
 
@@ -203,7 +184,7 @@ class NotesController extends Controller {
 			try {
 				// check if note still exists
 				$note = $this->notesService->get($this->helper->getUID(), $id);
-				$noteData = $note->getData();
+				$noteData = $this->helper->getNoteData($note);
 				if ($noteData['error']) {
 					throw new \Exception();
 				}
@@ -214,7 +195,7 @@ class NotesController extends Controller {
 				$note->setContent($content);
 				$note->setModified($modified);
 				$note->setFavorite($favorite);
-				return $note->getData();
+				return $this->helper->getNoteData($note);
 			}
 		});
 	}
@@ -241,10 +222,9 @@ class NotesController extends Controller {
 	 */
 	public function update(int $id, string $content) : JSONResponse {
 		return $this->helper->handleErrorResponse(function () use ($id, $content) {
-			$note = $this->notesService->get($this->helper->getUID(), $id);
+			$note = $this->helper->getNoteWithETagCheck($id, $this->request);
 			$note->setContent($content);
-			$this->metaService->update($this->helper->getUID(), $note);
-			return $note->getData();
+			return $this->helper->getNoteData($note);
 		});
 	}
 
